summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--Makefile.in2
-rw-r--r--README.cross10
-rw-r--r--RepositoryFixes.mk2
-rwxr-xr-xbin/symbolstore.py4
-rw-r--r--config_host/config_features.h.in2
-rw-r--r--configure.ac38
-rw-r--r--connectivity/com/sun/star/sdbcx/comp/hsqldb/NativeLibraries.java4
-rw-r--r--connectivity/source/drivers/macab/MacabConnection.cxx2
-rw-r--r--connectivity/source/drivers/macab/MacabGroup.cxx2
-rw-r--r--connectivity/source/drivers/macab/MacabRecords.cxx2
-rw-r--r--connectivity/source/drivers/macab/MacabRecords.hxx2
-rw-r--r--desktop/README6
-rw-r--r--desktop/source/app/app.cxx4
-rw-r--r--extensions/README2
-rw-r--r--extensions/source/abpilot/datasourcehandling.hxx2
-rw-r--r--extensions/source/abpilot/typeselectionpage.cxx6
-rw-r--r--external/curl/ExternalProject_curl.mk4
-rw-r--r--external/nss/README2
-rw-r--r--external/redland/raptor/raptor_config.h2
-rw-r--r--external/rhino/rhino1_5R5-updateToolTip.patch2
-rw-r--r--extras/source/autocorr/lang/hr/umetanje-automatskih-ispravaka.md2
-rw-r--r--fpicker/README2
-rw-r--r--fpicker/source/aqua/ControlHelper.mm2
-rw-r--r--fpicker/source/aqua/SalAquaPicker.mm2
-rw-r--r--include/sal/log-areas.dox4
-rw-r--r--include/svtools/strings.hrc2
-rw-r--r--include/vcl/svapp.hxx2
-rw-r--r--jurt/com/sun/star/lib/util/NativeLibraryLoader.java2
-rw-r--r--jvmfwk/plugins/sunmajor/pluginlib/util.cxx8
-rw-r--r--jvmfwk/plugins/sunmajor/pluginlib/util_cocoa.mm8
-rw-r--r--jvmfwk/plugins/sunmajor/pluginlib/vendorlist.cxx2
-rw-r--r--lingucomponent/source/spellcheck/macosxspell/macspellimp.mm4
-rw-r--r--odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java2
-rw-r--r--odk/examples/DevelopersGuide/OfficeBean/Makefile2
-rw-r--r--odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/Makefile2
-rw-r--r--offapi/com/sun/star/awt/Key.idl4
-rw-r--r--offapi/com/sun/star/awt/KeyModifier.idl4
-rw-r--r--onlineupdate/source/update/updater/updater.cxx6
-rw-r--r--osx/README4
-rw-r--r--sal/osl/unx/osxlocale.cxx2
-rw-r--r--sal/osl/unx/salinit.cxx4
-rw-r--r--sal/osl/unx/security.cxx2
-rw-r--r--sal/osl/unx/signal.cxx2
-rw-r--r--sal/osl/unx/system.cxx2
-rw-r--r--sal/osl/unx/uunxapi.cxx2
-rw-r--r--sal/qa/osl/module/osl_Module.cxx10
-rw-r--r--sal/rtl/math.cxx2
-rw-r--r--salhelper/source/gcc3.map4
-rw-r--r--sc/qa/unit/subsequent_export-test.cxx2
-rw-r--r--scripting/java/com/sun/star/script/framework/provider/SwingInvocation.java2
-rw-r--r--setup_native/source/mac/Info.plist.langpack2
-rw-r--r--sfx2/source/dialog/filedlghelper.cxx2
-rw-r--r--shell/source/backends/localebe/localebackend.cxx4
-rwxr-xr-xsolenv/bin/macosx-codesign-app-bundle2
-rw-r--r--solenv/bin/modules/installer/simplepackage.pm4
-rwxr-xr-xsolenv/gbuild/config.guess4
-rw-r--r--solenv/gbuild/platform/com_GCC_class.mk2
-rwxr-xr-xsolenv/gbuild/platform/unittest-failed-MACOSX.sh2
-rw-r--r--solenv/maven/README.md4
-rw-r--r--soltools/cpp/_getopt.c2
-rw-r--r--tools/source/datetime/systemdatetime.cxx2
-rw-r--r--ucb/source/ucp/file/filtask.cxx2
-rw-r--r--udkapi/com/sun/star/lang/SystemDependent.idl2
-rw-r--r--vcl/README4
-rw-r--r--vcl/osx/salframe.cxx4
-rw-r--r--vcl/osx/salnativewidgets.cxx4
-rw-r--r--vcl/quartz/ctfonts.cxx2
-rw-r--r--vcl/source/control/edit.cxx8
-rw-r--r--vcl/source/control/scrbar.cxx4
-rw-r--r--vcl/source/control/spinfld.cxx2
-rw-r--r--vcl/source/filter/igif/gifread.cxx2
-rw-r--r--vcl/source/treelist/transfer.cxx2
-rw-r--r--vcl/source/window/brdwin.cxx6
-rw-r--r--vcl/source/window/mouse.cxx2
-rw-r--r--vcl/source/window/window.cxx2
-rw-r--r--vcl/unx/generic/window/salframe.cxx4
-rw-r--r--vcl/unx/gtk/gtksalframe.cxx4
-rw-r--r--vcl/unx/gtk3/gtk3gtkframe.cxx2
78 files changed, 142 insertions, 142 deletions
diff --git a/Makefile.in b/Makefile.in
index 7cf5a9254233..2de08601c127 100644
--- a/Makefile.in
+++ b/Makefile.in
@@ -354,7 +354,7 @@ else
@$(SRCDIR)/solenv/bin/ooinstall $(TESTINSTALLDIR)
ifneq ($(MACOSX_CODESIGNING_IDENTITY),)
#
-# Create Resources/*.lproj directories for languages supported by OS X
+# Create Resources/*.lproj directories for languages supported by macOS
set -x; for lang in ca cs da de el en es fi fr hr hu id it ja ko ms nl no pl pt pt_PT ro ru sk sv th tr uk vi zh_CN zh_TW; do \
lproj=$(TESTINSTALLDIR)/$(PRODUCTNAME_WITHOUT_SPACES).app/Contents/Resources/$$lang.lproj; \
mkdir "$$lproj"; \
diff --git a/README.cross b/README.cross
index f7cb075a6096..0219dbc4bfcd 100644
--- a/README.cross
+++ b/README.cross
@@ -68,12 +68,12 @@ Obviously we want it to be possible to eventually distribute apps
using LibreOffice code through the App Store. Technically, one
important special aspect of iOS is that apps in the App Store are not
allowed to load own dynamic libraries. (System libraries are used in
-the form of dynamic libraries, just like on Mac OS X, of which iOS is
+the form of dynamic libraries, just like on macOS, of which iOS is
a variant.)
Thus all the libraries in LibreOffice that normally are shared
libraries (DLLs on Windows, shared objects (.so) on Linux, dynamic
-libraries on Mac OS X (.dylib)) must be built as static archives
+libraries on macOS (.dylib)) must be built as static archives
instead. This has some interesting consequences for how UNO is
implemented and used.
@@ -86,7 +86,7 @@ X. In order to be able to run and debug an app on an actual device
(and not just the iOS Simulator) you need to be registered in the iOS
Developer Program.
-Here is an autogen.input for iOS (device) using Xcode 4.6, on OS X 10.8:
+Here is an autogen.input for iOS (device) using Xcode 4.6, on macOS 10.8:
--build=i386-apple-darwin10.7.0
--host=arm-apple-darwin10
@@ -133,9 +133,9 @@ For the GUI, the same holds as said above for iOS. The GUI layer needs
to be platform-specific, written in Java.
Android cross-compilation work has been done mainly on Linux (openSUSE
-in particular). Earlier also cross-compiling from OS X was tried. The
+in particular). Earlier also cross-compiling from macOS was tried. The
Android cross-compilation tool-chain (the "Native Development Kit", or
-NDK) is available for Linux, OS X and Windows, but trying to
+NDK) is available for Linux, macOS and Windows, but trying to
cross-compile LibreOffice from Windows will probably drive you insane.
You will also need the Android SDK as full "make" also builds a couple
diff --git a/RepositoryFixes.mk b/RepositoryFixes.mk
index 55c69ef11dba..741f6bbfee21 100644
--- a/RepositoryFixes.mk
+++ b/RepositoryFixes.mk
@@ -42,7 +42,7 @@ gb_Executable_FILENAMES := $(patsubst soffice_com:soffice_com%,soffice_com:soffi
gb_Executable_FILENAMES_FOR_BUILD := $(subst $(gb_Executable_EXT),$(gb_Executable_EXT_for_build),$(gb_Executable_FILENAMES))
-# fixes for .jnilibs on Mac OS X that are not also needed as .dylibs:
+# fixes for .jnilibs on macOS that are not also needed as .dylibs:
ifeq ($(OS),MACOSX)
gb_Library_FILENAMES := \
$(subst jpipe:libjpipe.dylib,jpipe:libjpipe.jnilib,$(gb_Library_FILENAMES))
diff --git a/config_host/config_features.h.in b/config_host/config_features.h.in
index a7b08c7ddcfe..97c2a4f797db 100644
--- a/config_host/config_features.h.in
+++ b/config_host/config_features.h.in
@@ -92,7 +92,7 @@
#define HAVE_FEATURE_AVAHI 0
-/* MACOSX_SANDBOX - whether LibreOffice runs in an OS X sandbox
+/* MACOSX_SANDBOX - whether LibreOffice runs in a macOS sandbox
*
* When building LibreOffice for distribution through the Mac App Store,
* it must be sandboxed.
diff --git a/configure.ac b/configure.ac
index 426bbdf3cba0..947fc3920782 100644
--- a/configure.ac
+++ b/configure.ac
@@ -34,7 +34,7 @@ FilterLibs()
-L/lib|-L/lib/|-L/lib64|-L/lib64/|-L/usr/lib|-L/usr/lib/|-L/usr/lib64|-L/usr/lib64/)
# ignore it: on UNIXoids it is searched by default anyway
# but if it's given explicitly then it may override other paths
- # (on Mac OS X it would be an error to use it instead of SDK)
+ # (on macOS it would be an error to use it instead of SDK)
;;
*)
filteredlibs="$filteredlibs $f"
@@ -469,7 +469,7 @@ if test -n "$with_android_ndk"; then
ndk_build_os=darwin
;;
*)
- AC_MSG_ERROR([We only support building for Android from Linux or OS X])
+ AC_MSG_ERROR([We only support building for Android from Linux or macOS])
;;
esac
ANDROID_COMPILER_BIN=$ANDROID_COMPILER_DIR/prebuilt/$ndk_build_os-x86_64/bin
@@ -641,7 +641,7 @@ cygwin*|interix*)
LINKFLAGSNOUNDEFS=
;;
-darwin*) # Mac OS X or iOS
+darwin*) # macOS or iOS
test_gtk=yes
test_randr=no
test_xrender=no
@@ -1437,7 +1437,7 @@ AC_ARG_ENABLE(macosx-sandbox,
AC_ARG_WITH(macosx-bundle-identifier,
AS_HELP_STRING([--with-macosx-bundle-identifier=tld.mumble.orifice.TheOffice],
- [Define the OS X bundle identifier. Default is the somewhat weird
+ [Define the macOS bundle identifier. Default is the somewhat weird
org.libreoffice.script ("script", huh?).]),
,with_macosx_bundle_identifier=org.libreoffice.script)
@@ -2701,7 +2701,7 @@ dnl ENABLE_JAVA="TRUE" if we want there to be *run-time* (and build-time) suppor
dnl ENABLE_JAVA="" indicate no Java support at all
dnl ===================================================================
-dnl Check OS X SDK and compiler
+dnl Check macOS SDK and compiler
dnl ===================================================================
if test $_os = Darwin -o $_os = iOS; then
@@ -2714,7 +2714,7 @@ if test $_os = Darwin -o $_os = iOS; then
# For developers with a current Xcode, the lowest-numbered SDK
# higher than or equal to the minimum required should be found.
- AC_MSG_CHECKING([what Mac OS X SDK to use])
+ AC_MSG_CHECKING([what macOS SDK to use])
for _macosx_sdk in ${with_macosx_sdk-10.14 10.13 10.12}; do
MACOSX_SDK_PATH=`xcrun --sdk macosx${_macosx_sdk} --show-sdk-path 2> /dev/null`
if test -d "$MACOSX_SDK_PATH"; then
@@ -2729,7 +2729,7 @@ if test $_os = Darwin -o $_os = iOS; then
fi
done
if test ! -d "$MACOSX_SDK_PATH"; then
- AC_MSG_ERROR([Could not find an appropriate Mac OS X SDK])
+ AC_MSG_ERROR([Could not find an appropriate macOS SDK])
fi
if test $_os = iOS; then
@@ -2919,9 +2919,9 @@ if test $_os = Darwin -o $_os = iOS; then
AC_MSG_CHECKING([whether to sandbox the application])
if test -z "$MACOSX_CODESIGNING_IDENTITY" -a "$enable_macosx_sandbox" = yes; then
- AC_MSG_ERROR([OS X sandboxing requires code signing])
+ AC_MSG_ERROR([macOS sandboxing requires code signing])
elif test -n "$ENABLE_JAVA" -a "$enable_macosx_sandbox" = yes; then
- AC_MSG_ERROR([OS X sandboxing (actually App Store rules) disallows use of Java])
+ AC_MSG_ERROR([macOS sandboxing (actually App Store rules) disallows use of Java])
elif test -n "$MACOSX_CODESIGNING_IDENTITY" -a "$enable_macosx_sandbox" = yes; then
ENABLE_MACOSX_SANDBOX=TRUE
AC_DEFINE(HAVE_FEATURE_MACOSX_SANDBOX)
@@ -2930,7 +2930,7 @@ if test $_os = Darwin -o $_os = iOS; then
AC_MSG_RESULT([no])
fi
- AC_MSG_CHECKING([what OS X app bundle identifier to use])
+ AC_MSG_CHECKING([what macOS app bundle identifier to use])
MACOSX_BUNDLE_IDENTIFIER=$with_macosx_bundle_identifier
AC_MSG_RESULT([$MACOSX_BUNDLE_IDENTIFIER])
fi
@@ -2940,7 +2940,7 @@ AC_SUBST(MAC_OS_X_VERSION_MIN_REQUIRED)
AC_SUBST(MAC_OS_X_VERSION_MIN_REQUIRED_DOTS)
AC_SUBST(MAC_OS_X_VERSION_MAX_ALLOWED)
AC_SUBST(INSTALL_NAME_TOOL)
-AC_SUBST(LIBTOOL) # Note that the OS X libtool command is unrelated to GNU libtool
+AC_SUBST(LIBTOOL) # Note that the macOS libtool command is unrelated to GNU libtool
AC_SUBST(MACOSX_CODESIGNING_IDENTITY)
AC_SUBST(MACOSX_PACKAGE_SIGNING_IDENTITY)
AC_SUBST(ENABLE_MACOSX_SANDBOX)
@@ -4468,7 +4468,7 @@ rpm - RedHat software distribution
LibreOffice additionally supports:
archive - .tar.gz or .zip
-dmg - Mac OS X .dmg
+dmg - macOS .dmg
installed - installation tree
msi - Windows .msi
])
@@ -4824,7 +4824,7 @@ else
fi
AC_SUBST(WITH_MYSPELL_DICTS)
-# There are no "system" myspell, hyphen or mythes dictionaries on OS X, Windows, Android or iOS.
+# There are no "system" myspell, hyphen or mythes dictionaries on macOS, Windows, Android or iOS.
if test $_os = Darwin -o $_os = WINNT -o $_os = iOS -o $_os = Android; then
if test "$with_system_dicts" = yes; then
AC_MSG_ERROR([There are no system dicts on this OS in the formats the 3rd-party libs we use expect]);
@@ -5148,7 +5148,7 @@ AC_SUBST(STRIP)
AC_SUBST(WINDRES)
dnl ===================================================================
-dnl pkg-config checks on Mac OS X
+dnl pkg-config checks on macOS
dnl ===================================================================
if test $_os = Darwin; then
@@ -6868,7 +6868,7 @@ if test "$ENABLE_JAVA" != ""; then
fi
fi
- # MacOS X: /usr/libexec/java_home helps to set the current JDK_HOME. Actually JDK_HOME should NOT be set where java (/usr/bin/java) is located.
+ # macOS: /usr/libexec/java_home helps to set the current JDK_HOME. Actually JDK_HOME should NOT be set where java (/usr/bin/java) is located.
# /usr/bin/java -> /System/Library/Frameworks/JavaVM.framework/Versions/Current/Commands/java, but /usr does not contain the JDK libraries
if test -z "$with_jdk_home" -a "$_os" = "Darwin" -a -x /usr/libexec/java_home; then
with_jdk_home=`/usr/libexec/java_home`
@@ -7681,7 +7681,7 @@ if test "$with_system_zlib" = "auto"; then
esac
fi
-dnl we want to use libo_CHECK_SYSTEM_MODULE here too, but OS X is too stupid
+dnl we want to use libo_CHECK_SYSTEM_MODULE here too, but macOS is too stupid
dnl and has no pkg-config for it at least on some tinderboxes,
dnl so leaving that out for now
dnl libo_CHECK_SYSTEM_MODULE([zlib],[ZLIB],[zlib])
@@ -8624,7 +8624,7 @@ if test "x$enable_postgresql_sdbc" != "xno"; then
WITH_GSSAPI=
case "$_os" in
Darwin)
- # MacOS X has system MIT Kerberos 5 since 10.4
+ # macOS has system MIT Kerberos 5 since 10.4
if test "$with_krb5" != "no"; then
WITH_KRB5=TRUE
save_LIBS=$LIBS
@@ -9862,7 +9862,7 @@ if test -z "$PATCH"; then
AC_MSG_ERROR(["patch" not found in \$PATH, install it])
fi
-dnl On Solaris, FreeBSD or MacOS X, check if --with-gnu-patch was used
+dnl On Solaris, FreeBSD or macOS, check if --with-gnu-patch was used
if test "$_os" = "SunOS" -o "$_os" = "FreeBSD" -o "$_os" = "Darwin"; then
if test -z "$with_gnu_patch"; then
GNUPATCH=$PATCH
@@ -10367,7 +10367,7 @@ ENABLE_OPENGL_CANVAS=
if test $_os = iOS -o $_os = Android -o "$ENABLE_FUZZERS" = "TRUE"; then
: # disable
elif test "$_os" = "Darwin"; then
- # We use frameworks on Mac OS X, no need for detail checks
+ # We use frameworks on macOS, no need for detail checks
ENABLE_OPENGL_TRANSITIONS=TRUE
AC_DEFINE(HAVE_FEATURE_OPENGL,1)
ENABLE_OPENGL_CANVAS=TRUE
diff --git a/connectivity/com/sun/star/sdbcx/comp/hsqldb/NativeLibraries.java b/connectivity/com/sun/star/sdbcx/comp/hsqldb/NativeLibraries.java
index 59541556b185..e8ea8d44eea2 100644
--- a/connectivity/com/sun/star/sdbcx/comp/hsqldb/NativeLibraries.java
+++ b/connectivity/com/sun/star/sdbcx/comp/hsqldb/NativeLibraries.java
@@ -33,10 +33,10 @@ final class NativeLibraries {
}
private static void loadLibrary(String libname) {
- // At least on Mac OS X Tiger, System.loadLibrary("hsqldb2") does not
+ // At least on macOS Tiger, System.loadLibrary("hsqldb2") does not
// find the hsqldb2 library one directory above sdbc_hsqldb.jar, even
// though ".." is on the jar's Class-Path; however, the alternative
- // code (needing Java 1.5, which is given for Mac OS X Tiger) works
+ // code (needing Java 1.5, which is given for macOS Tiger) works
// there:
try {
System.loadLibrary(libname);
diff --git a/connectivity/source/drivers/macab/MacabConnection.cxx b/connectivity/source/drivers/macab/MacabConnection.cxx
index eeea86def136..e55d342584d8 100644
--- a/connectivity/source/drivers/macab/MacabConnection.cxx
+++ b/connectivity/source/drivers/macab/MacabConnection.cxx
@@ -57,7 +57,7 @@ void MacabConnection::construct(const OUString&, const Sequence< PropertyValue >
{
osl_atomic_increment( &m_refCount );
- // get the Mac OS X shared address book
+ // get the macOS shared address book
m_pAddressBook = new MacabAddressBook();
osl_atomic_decrement( &m_refCount );
diff --git a/connectivity/source/drivers/macab/MacabGroup.cxx b/connectivity/source/drivers/macab/MacabGroup.cxx
index f4217b018aac..a57f1729fc2d 100644
--- a/connectivity/source/drivers/macab/MacabGroup.cxx
+++ b/connectivity/source/drivers/macab/MacabGroup.cxx
@@ -27,7 +27,7 @@ using namespace connectivity::macab;
/* A MacabGroup is basically a MacabRecords with a different constructor.
* It only exists as a different entity for clarification purposes (a group
- * is its own entity in the Mac OS X Address Book) and because its
+ * is its own entity in the macOS Address Book) and because its
* construction is so unique (it is based on an already existent
* MacabRecords of the entire address book).
*/
diff --git a/connectivity/source/drivers/macab/MacabRecords.cxx b/connectivity/source/drivers/macab/MacabRecords.cxx
index 675757cf629c..19fa868a2b28 100644
--- a/connectivity/source/drivers/macab/MacabRecords.cxx
+++ b/connectivity/source/drivers/macab/MacabRecords.cxx
@@ -349,7 +349,7 @@ MacabHeader *MacabRecords::createHeaderForRecordType(const CFArrayRef _records,
* at least one record in the set has that property filled. The reason
* is that some properties, like the kABTitleProperty are required by
* the mail merge wizard (in module sw) but are by default not shown in
- * the Mac OS X address book, so they would be weeded out at this stage
+ * the macOS address book, so they would be weeded out at this stage
* and not shown if they were not required.
*
* Note: with the addition of required properties, I am not sure that
diff --git a/connectivity/source/drivers/macab/MacabRecords.hxx b/connectivity/source/drivers/macab/MacabRecords.hxx
index 9fe357b6f850..1e7d9975de15 100644
--- a/connectivity/source/drivers/macab/MacabRecords.hxx
+++ b/connectivity/source/drivers/macab/MacabRecords.hxx
@@ -69,7 +69,7 @@ namespace connectivity
/* All of the private methods are for creating a MacabHeader or a
* MacabRecord. They are used by the initialize method that goes
* about filling a MacabRecords using all of the records in the
- * Mac OS X Address Book.
+ * macOS Address Book.
*/
void bootstrap_CF_types();
void bootstrap_requiredProperties();
diff --git a/desktop/README b/desktop/README
index d82078edddbe..a49f0051ae1f 100644
--- a/desktop/README
+++ b/desktop/README
@@ -11,13 +11,13 @@ soffice
=======
In the "program" directory ("program/" on Linux and Windows, "Contents/MacOS/"
-on Mac OS X).
+on macOS).
unoinfo
=======
In the "program" directory ("program/" on Linux and Windows, "Contents/MacOS/"
-on Mac OS X).
+on macOS).
When called with a sole argument of "c++", it prints to stdout an absolute
pathname denoting the directory where the public URE libraries are found.
@@ -27,7 +27,7 @@ character (either an ASCII '0' or '1') followed by a sequence of zero or more
absolute pathnames denoting jars or directories that need to be included in a
class loader's search locations.
-If the marker character is '0' (on Linux and Mac OS X), the pathnames are
+If the marker character is '0' (on Linux and macOS), the pathnames are
encoded as bytes, and any two pathnames in the sequence are separated from each
other by NUL bytes.
diff --git a/desktop/source/app/app.cxx b/desktop/source/app/app.cxx
index 257925d71cfa..2291aeb171f4 100644
--- a/desktop/source/app/app.cxx
+++ b/desktop/source/app/app.cxx
@@ -1101,7 +1101,7 @@ void restartOnMac(bool passArguments) {
}
argPtrs.push_back(nullptr);
execv(execPath8.getStr(), const_cast< char ** >(&argPtrs[0]));
- if (errno == ENOTSUP) { // happens when multithreaded on OS X < 10.6
+ if (errno == ENOTSUP) { // happens when multithreaded on macOS < 10.6
pid_t pid = fork();
if (pid == 0) {
execv(execPath8.getStr(), const_cast< char ** >(&argPtrs[0]));
@@ -1843,7 +1843,7 @@ bool Desktop::InitializeQuickstartMode( const Reference< XComponentContext >& rx
// unfortunately this broke the Mac behavior which is to always run
// in quickstart mode since Mac applications do not usually quit
// when the last document closes.
- // Note that this claim that on OS X we "always run in quickstart mode"
+ // Note that this claim that on macOS we "always run in quickstart mode"
// has nothing to do with (quick) *starting* (i.e. starting automatically
// when the user logs in), though, but with not quitting when no documents
// are open.
diff --git a/extensions/README b/extensions/README
index b74ff369baa1..38df77e37fba 100644
--- a/extensions/README
+++ b/extensions/README
@@ -35,7 +35,7 @@ See extensions/source/activex/
== Spotlight provider ==
-On Mac OS X, this allows indexing ODF documents with Spotlight.
+On macOS, this allows indexing ODF documents with Spotlight.
See extensions/source/macosx/spotlight/
== Scanner support ==
diff --git a/extensions/source/abpilot/datasourcehandling.hxx b/extensions/source/abpilot/datasourcehandling.hxx
index f7f794fd41cf..5a73f5ac6b04 100644
--- a/extensions/source/abpilot/datasourcehandling.hxx
+++ b/extensions/source/abpilot/datasourcehandling.hxx
@@ -77,7 +77,7 @@ namespace abp
/// creates a new KDE address book data source
ODataSource createNewKab( const OUString& _rName );
- /// creates a new Mac OS X address book data source
+ /// creates a new macOS address book data source
ODataSource createNewMacab( const OUString& _rName );
/// creates a new dBase data source
diff --git a/extensions/source/abpilot/typeselectionpage.cxx b/extensions/source/abpilot/typeselectionpage.cxx
index d4decd9dc995..5e3d49e1cb1d 100644
--- a/extensions/source/abpilot/typeselectionpage.cxx
+++ b/extensions/source/abpilot/typeselectionpage.cxx
@@ -47,7 +47,7 @@ namespace abp
//TODO: For now, try to keep offering the same choices like before the
// Mozilla/MORK cleanup, even if the status of what driver actually
// provides which functionality is somewhat unclear, see the discussions
- // of fdo#57285 "Address Book Data Source Wizard lists 'Mac OS X address
+ // of fdo#57285 "Address Book Data Source Wizard lists 'macOS address
// book' on Linux" and fdo#57322 "Moz-free LDAP Address Book driver."
// In accordance with ancient OOo 3.3, this is as follows:
//
@@ -57,7 +57,7 @@ namespace abp
// - KAB (if applicable)
// - OTHER
//
- // On Mac OS X:
+ // On macOS:
// - MACAB (if applicable)
// - MORK (via mork driver, which is built unconditionally)
// - OTHER
@@ -97,7 +97,7 @@ namespace abp
try
{
- // check whether Mac OS X address book is available
+ // check whether macOS address book is available
Reference< XDriver > xDriver( xManager->getDriverByURL("sdbc:address:macab") );
if ( xDriver.is() )
bHaveMacab = true;
diff --git a/external/curl/ExternalProject_curl.mk b/external/curl/ExternalProject_curl.mk
index 73d5620eaa01..86e22aa2fa19 100644
--- a/external/curl/ExternalProject_curl.mk
+++ b/external/curl/ExternalProject_curl.mk
@@ -35,8 +35,8 @@ ifeq ($(SYSTEM_NSS),)
curl_CPPFLAGS += -I$(call gb_UnpackedTarball_get_dir,nss)/dist/public/nss
endif
-# use --with-darwinssl on Mac OS X >10.5 and iOS to get a native UI for SSL certs for CMIS usage
-# use --with-nss only on platforms other than Mac OS X and iOS
+# use --with-darwinssl on macOS >10.5 and iOS to get a native UI for SSL certs for CMIS usage
+# use --with-nss only on platforms other than macOS and iOS
$(call gb_ExternalProject_get_state_target,curl,build):
$(call gb_ExternalProject_run,build,\
./configure \
diff --git a/external/nss/README b/external/nss/README
index d4fbd68bd193..6997cea6ca06 100644
--- a/external/nss/README
+++ b/external/nss/README
@@ -16,7 +16,7 @@ See also
== libsqlite3 ==
-With all supported Mac OS X SDK we use
+With all supported macOS SDK we use
NSS_USE_SYSTEM_SQLITE=1
to build using the system sqlite.
diff --git a/external/redland/raptor/raptor_config.h b/external/redland/raptor/raptor_config.h
index 3e94fee947ad..74f58de95e94 100644
--- a/external/redland/raptor/raptor_config.h
+++ b/external/redland/raptor/raptor_config.h
@@ -332,7 +332,7 @@
`char[]'. */
#undef YYTEXT_POINTER
-/* Enable large inode numbers on Mac OS X 10.5. */
+/* Enable large inode numbers on macOS 10.5. */
#ifndef _DARWIN_USE_64_BIT_INODE
# define _DARWIN_USE_64_BIT_INODE 1
#endif
diff --git a/external/rhino/rhino1_5R5-updateToolTip.patch b/external/rhino/rhino1_5R5-updateToolTip.patch
index 16857d35fca6..be0700daf6c5 100644
--- a/external/rhino/rhino1_5R5-updateToolTip.patch
+++ b/external/rhino/rhino1_5R5-updateToolTip.patch
@@ -9,7 +9,7 @@
private void updateToolTip() {
- // in case fileName is very long, try to set tool tip on frame
- Component c = getComponent(1);
-+ // Try to set tool tip on frame. On Mac OS X 10.5,
++ // Try to set tool tip on frame. On macOS 10.5,
+ // the number of components is different, so try to be safe.
+ int n = getComponentCount() - 1;
+ if (n > 1) {
diff --git a/extras/source/autocorr/lang/hr/umetanje-automatskih-ispravaka.md b/extras/source/autocorr/lang/hr/umetanje-automatskih-ispravaka.md
index b57736282702..83b2de86257e 100644
--- a/extras/source/autocorr/lang/hr/umetanje-automatskih-ispravaka.md
+++ b/extras/source/autocorr/lang/hr/umetanje-automatskih-ispravaka.md
@@ -9,7 +9,7 @@ Vrlo je jednostavno dodati noviju inačicu pravila za automatsko ispravljanje u
* tako preimenovanu datoteku kopirajte
* na **GNU/Linuxu** u datoteku **/home/&lt;user name&gt;/.config/libreOffice/4/user/autocorr**. Zamijenite &lt;user name&gt; vašim korisničkim imenom. Ako vam je korisničko ime za prijavu u sustav 'marko', onda datoteku treba kopirati u direktorij /home/marko/.config/libreOffice/4/user/autocorr. Staru acor_hr-HR.dat datoteku nemojte brisati, preimenujte je u 'backup-acor_hr-HR.dat za svaki slučaj
* na **Windows** operacijskom sustavu u datoteku **%APPDATA%\libreoffice\4\user\autocorr** gdje %APPDATA% treba zamijeniti putanjom gdje se na vašem sustavu i inače instaliraju aplikacije. Najvjerojatnije **C:\Users&#92;&lt;user name&gt;\AppData\Roaming\libreoffice\4\user\autocorr**. Isto tako &lt;user name&gt; trebate zamijeniti vašim korisnički imenom. Ako vam je korisničko ime za prijavu u sustav 'marko' onda datoteku acor_hr-HR.dat treba kopirati u C:\Users\marko\AppData\Roaming\libreoffice\4\user\autocorr.
- * na **Mac OS X** operacijskom sustavu datoteku acor_hr-HR.dat treba kopirati u mapu **/Users/&lt;user name&gt;/Library/Application Support/LibreOffice/4/user/autocorr**. Zamijenite &lt;user name&gt; vašim korisnički imenom. Ako vam je korisničko ime za prijavu u sustav 'marko', datoteku treba kopirati u mapu /Users/marko/Library/Application Support/LibreOffice/4/user/autocorr.
+ * na **macOS** operacijskom sustavu datoteku acor_hr-HR.dat treba kopirati u mapu **/Users/&lt;user name&gt;/Library/Application Support/LibreOffice/4/user/autocorr**. Zamijenite &lt;user name&gt; vašim korisnički imenom. Ako vam je korisničko ime za prijavu u sustav 'marko', datoteku treba kopirati u mapu /Users/marko/Library/Application Support/LibreOffice/4/user/autocorr.
* Ponovno pokrenite LibreOffice. Vodite računa da zatvorite i pokrenutu instanciju LibreOfficea u sistemskoj traci ako vam ja uključeno brzo pokretanje (engl. Quickstarter).
Ako niste sigurni u koju mapu trebate kopirati **acor_hr-HR.dat** datoteku, otvorite LibreOffice, u izborniku **Alati** odaberite **Mogućnosti**, s lijeve strane dijaloškog okvira odaberite stavku **LibreOffice** te ispod te kategorije odaberite **Putanje** i pogledajte koja putanja na desnoj strani stoji uz **Automatsko ispravljanje**.
diff --git a/fpicker/README b/fpicker/README
index e0366e0a32d8..ea21095c1601 100644
--- a/fpicker/README
+++ b/fpicker/README
@@ -1 +1 @@
-Native file pickers for OS X and Windows (file open dialog).
+Native file pickers for macOS and Windows (file open dialog).
diff --git a/fpicker/source/aqua/ControlHelper.mm b/fpicker/source/aqua/ControlHelper.mm
index cd67c04b037f..70cbbf190238 100644
--- a/fpicker/source/aqua/ControlHelper.mm
+++ b/fpicker/source/aqua/ControlHelper.mm
@@ -583,7 +583,7 @@ void ControlHelper::createControls()
}
}
- //preview is always on with Mac OS X
+ //preview is always on with macOS
NSControl *pPreviewBox = m_pToggles[PREVIEW];
if (pPreviewBox != nil) {
[pPreviewBox setEnabled:NO];
diff --git a/fpicker/source/aqua/SalAquaPicker.mm b/fpicker/source/aqua/SalAquaPicker.mm
index b6f40989e9cb..0b235bb92dff 100644
--- a/fpicker/source/aqua/SalAquaPicker.mm
+++ b/fpicker/source/aqua/SalAquaPicker.mm
@@ -89,7 +89,7 @@ void SalAquaPicker::implInitialize()
* [(NSSavePanel*)m_pDialog setExtensionHidden:YES];
* here but unfortunately this
* a) only works when the dialog is already displayed because it seems to act on the corresponding checkbox (that we don't show but that doesn't matter)
- * b) Mac OS X saves this setting on an application-based level which means that the last state is always being restored again when the app runs for the next time
+ * b) macOS saves this setting on an application-based level which means that the last state is always being restored again when the app runs for the next time
*
* So the only reliable way seems to be using the NSUserDefaults object because that is where that value is stored and
* to just overwrite it if it has the wrong value.
diff --git a/include/sal/log-areas.dox b/include/sal/log-areas.dox
index c2ff84627248..1468680d065e 100644
--- a/include/sal/log-areas.dox
+++ b/include/sal/log-areas.dox
@@ -456,9 +456,9 @@ certain functionality.
@li @c vcl
@li @c vcl.a11y
@li @c vcl.app
-@li @c vcl.cg - CoreGraphics calls on OS X and iOS
+@li @c vcl.cg - CoreGraphics calls on macOS and iOS
@li @c vcl.control
-@li @c vcl.ct - CoreText-using code for OS X and iOS
+@li @c vcl.ct - CoreText-using code for macOS and iOS
@li @c vcl.debugevent
@li @c vcl.emf - EMF/EMF+ processing
@li @c vcl.eventtesting
diff --git a/include/svtools/strings.hrc b/include/svtools/strings.hrc
index 84987002c7fb..efd5ece4efa8 100644
--- a/include/svtools/strings.hrc
+++ b/include/svtools/strings.hrc
@@ -283,7 +283,7 @@
#define STR_WARNING_JAVANOTFOUND NC_("STR_WARNING_JAVANOTFOUND", "%PRODUCTNAME requires a Java runtime environment (JRE) to perform this task. Please install a JRE and restart %PRODUCTNAME.")
#define STR_WARNING_JAVANOTFOUND_WIN NC_("STR_WARNING_JAVANOTFOUND_WIN", "%PRODUCTNAME requires a %BITNESS-bit Java runtime environment (JRE) to perform this task. Please install a JRE and restart %PRODUCTNAME.")
-#define STR_WARNING_JAVANOTFOUND_MAC NC_("STR_WARNING_JAVANOTFOUND_MAC", "%PRODUCTNAME requires Oracle's Java Development Kit (JDK) on Mac OS X 10.10 or greater to perform this task. Please install them and restart %PRODUCTNAME.")
+#define STR_WARNING_JAVANOTFOUND_MAC NC_("STR_WARNING_JAVANOTFOUND_MAC", "%PRODUCTNAME requires Oracle's Java Development Kit (JDK) on macOS 10.10 or greater to perform this task. Please install them and restart %PRODUCTNAME.")
#define STR_WARNING_INVALIDJAVASETTINGS_MAC NC_("STR_WARNING_INVALIDJAVASETTINGS_MAC", "The %PRODUCTNAME configuration has been changed. Under %PRODUCTNAME - Preferences - %PRODUCTNAME - Advanced, select the Java runtime environment you want to have used by %PRODUCTNAME.")
#define STR_WARNING_INVALIDJAVASETTINGS NC_("STR_WARNING_INVALIDJAVASETTINGS", "The %PRODUCTNAME configuration has been changed. Under Tools - Options - %PRODUCTNAME - Advanced, select the Java runtime environment you want to have used by %PRODUCTNAME.")
#define STR_ERROR_JVMCREATIONFAILED_MAC NC_("STR_ERROR_JVMCREATIONFAILED_MAC", "%PRODUCTNAME requires a Java runtime environment (JRE) to perform this task. The selected JRE is defective. Please select another version or install a new JRE and select it under %PRODUCTNAME - Preferences - %PRODUCTNAME - Advanced.")
diff --git a/include/vcl/svapp.hxx b/include/vcl/svapp.hxx
index 3a43ee2c7386..9032ebc7f299 100644
--- a/include/vcl/svapp.hxx
+++ b/include/vcl/svapp.hxx
@@ -1025,7 +1025,7 @@ public:
/** @name Accelerators and Mnemonics
- Accelerators allow a user to hold down Ctrl+key (or CMD+key on OS X)
+ Accelerators allow a user to hold down Ctrl+key (or CMD+key on macOS)
combination to gain quick access to functionality.
Mnemonics are underline letters in things like menus and dialog boxes
diff --git a/jurt/com/sun/star/lib/util/NativeLibraryLoader.java b/jurt/com/sun/star/lib/util/NativeLibraryLoader.java
index ab1eabb9cb67..eb5c6af34e90 100644
--- a/jurt/com/sun/star/lib/util/NativeLibraryLoader.java
+++ b/jurt/com/sun/star/lib/util/NativeLibraryLoader.java
@@ -109,7 +109,7 @@ public final class NativeLibraryLoader {
if (path.exists()) {
return path;
}
- // On OS X, dir is now the Resources dir,
+ // On macOS, dir is now the Resources dir,
// we want to look in Frameworks
if (System.getProperty("os.name").startsWith("Mac")
&& dir.getName().equals("Resources")) {
diff --git a/jvmfwk/plugins/sunmajor/pluginlib/util.cxx b/jvmfwk/plugins/sunmajor/pluginlib/util.cxx
index 02cd94b295d2..36dd03877c0d 100644
--- a/jvmfwk/plugins/sunmajor/pluginlib/util.cxx
+++ b/jvmfwk/plugins/sunmajor/pluginlib/util.cxx
@@ -399,7 +399,7 @@ bool getJavaProps(const OUString & exePath,
OUString usStartDir;
//We need to set the CLASSPATH in case the office is started from
//a different directory. The JREProperties.class is expected to reside
- //next to the plugin, except on OS X where it is in ../Resources/java relative
+ //next to the plugin, except on macOS where it is in ../Resources/java relative
//to the plugin.
OUString sThisLib;
if (!osl_getModuleURLFromAddress(reinterpret_cast<void *>(&getJavaProps),
@@ -1137,7 +1137,7 @@ void addJavaInfoFromJavaHome(
#if !defined JVM_ONE_PATH_CHECK
// Get Java from JAVA_HOME environment
- // Note that on OS X is it not normal at all to have a JAVA_HOME environment
+ // Note that on macOS is it not normal at all to have a JAVA_HOME environment
// variable. We set it in our build environment for build-time programs, though,
// so it is set when running unit tests that involve Java functionality. (Which affects
// at least CppunitTest_dbaccess_dialog_save, too, and not only the JunitTest ones.)
@@ -1188,8 +1188,8 @@ void addJavaInfosDirScan(
{
#ifdef MACOSX
// Ignore all but Oracle's JDK as loading Apple's Java and Oracle's JRE
- // will cause OS X's JavaVM framework to display a dialog and invoke
- // exit() when loaded via JNI on OS X 10.10
+ // will cause macOS's JavaVM framework to display a dialog and invoke
+ // exit() when loaded via JNI on macOS 10.10
Directory aDir("file:///Library/Java/JavaVirtualMachines");
if (aDir.open() == File::E_None)
{
diff --git a/jvmfwk/plugins/sunmajor/pluginlib/util_cocoa.mm b/jvmfwk/plugins/sunmajor/pluginlib/util_cocoa.mm
index 5a5d7303a18a..136518253cde 100644
--- a/jvmfwk/plugins/sunmajor/pluginlib/util_cocoa.mm
+++ b/jvmfwk/plugins/sunmajor/pluginlib/util_cocoa.mm
@@ -24,8 +24,8 @@ bool JvmfwkUtil_isLoadableJVM( OUString const & aURL )
NSURL *pURL = nil;
// Ignore all but Oracle's JDK as loading Apple's Java and Oracle's
- // JRE will cause OS X's JavaVM framework to display a dialog and
- // invoke exit() when loaded via JNI on OS X 10.10
+ // JRE will cause macOS's JavaVM framework to display a dialog and
+ // invoke exit() when loaded via JNI on macOS 10.10
NSURL *pTmpURL = [NSURL URLWithString:pString];
if ( pTmpURL )
pTmpURL = [pTmpURL filePathURL];
@@ -69,9 +69,9 @@ bool JvmfwkUtil_isLoadableJVM( OUString const & aURL )
// Make sure that this bundle's Info.plist has the
// proper JVM keys to supports loading via JNI. If
// this bundle is a valid JVM and these keys
- // are missing, loading the JVM will cause OS X's
+ // are missing, loading the JVM will cause macOS's
// JavaVM framework to display a dialog and invoke
- // exit() when loaded via JNI on OS X 10.10.
+ // exit() when loaded via JNI on macOS 10.10.
NSDictionary *pInfo = [pBundle infoDictionary];
if ( pInfo )
{
diff --git a/jvmfwk/plugins/sunmajor/pluginlib/vendorlist.cxx b/jvmfwk/plugins/sunmajor/pluginlib/vendorlist.cxx
index 608be1583b8e..e44997625df1 100644
--- a/jvmfwk/plugins/sunmajor/pluginlib/vendorlist.cxx
+++ b/jvmfwk/plugins/sunmajor/pluginlib/vendorlist.cxx
@@ -35,7 +35,7 @@ namespace jfw_plugin
by "\xXX\xXX"
*/
BEGIN_VENDOR_MAP()
-// For OS X, don't bother with implementations that aren't relevant (or have never existed)
+// For macOS, don't bother with implementations that aren't relevant (or have never existed)
#ifdef MACOSX
VENDOR_MAP_ENTRY("Apple Inc.", OtherInfo)
VENDOR_MAP_ENTRY("Apple Computer, Inc.", OtherInfo)
diff --git a/odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java b/odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java
index 81a4e8fb8564..f5ef2a97088c 100644
--- a/odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java
+++ b/odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java
@@ -304,7 +304,7 @@ public class AsyncJob extends WeakBase implements XServiceInfo, XAsyncJob
final String sFinalTitle = sTitle;
final String sFinalMessage = sMessage;
- // On Mac OS X, AWT/Swing must not be accessed from the AppKit thread, so call
+ // On macOS, AWT/Swing must not be accessed from the AppKit thread, so call
// SwingUtilities.invokeLater always on a fresh thread to avoid that problem
// (also, the current thread must not wait for that fresh thread to terminate,
// as that would cause a deadlock if this thread is the AppKit thread):
diff --git a/odk/examples/DevelopersGuide/OfficeBean/Makefile b/odk/examples/DevelopersGuide/OfficeBean/Makefile
index 2dfc678ee9e2..4fce60578b58 100644
--- a/odk/examples/DevelopersGuide/OfficeBean/Makefile
+++ b/odk/examples/DevelopersGuide/OfficeBean/Makefile
@@ -61,7 +61,7 @@ SDK_CLASSPATH = $(subst $(EMPTYSTRING) $(PATH_SEPARATOR),$(PATH_SEPARATOR),$(URE
.PHONY: ALL
ifeq "$(OS)" "MACOSX"
ALL :
- @printf 'This example does not work on Mac OS X\n'
+ @printf 'This example does not work on macOS\n'
else
ALL : \
OOoBeanViewer
diff --git a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/Makefile b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/Makefile
index 2048ade63d98..b4179de724b2 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/Makefile
+++ b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/Makefile
@@ -82,7 +82,7 @@ endif
.PHONY: ALL
ifeq "$(OS)" "MACOSX"
ALL :
- @printf 'This example does not work on Mac OS X\n'
+ @printf 'This example does not work on macOS\n'
else
ALL : $(SUBDIR) \
$(EXAMPLE_NAME)
diff --git a/offapi/com/sun/star/awt/Key.idl b/offapi/com/sun/star/awt/Key.idl
index b3358441fadc..7ad04ae2206f 100644
--- a/offapi/com/sun/star/awt/Key.idl
+++ b/offapi/com/sun/star/awt/Key.idl
@@ -25,7 +25,7 @@
/** These values are used to specify distinct physical keys, plus
- some special values used by the OS X implementation.
+ some special values used by the macOS implementation.
*/
published constants Key
{
@@ -368,7 +368,7 @@ published constants Key
/** The following values don't correspond to physical keys on any
- keyboard but are used in the OS X implementation of VCL. They
+ keyboard but are used in the macOS implementation of VCL. They
correspond to some of the action messages of the NSResponder
abstract class.
*/
diff --git a/offapi/com/sun/star/awt/KeyModifier.idl b/offapi/com/sun/star/awt/KeyModifier.idl
index 697a00d03d3f..c1dbf5044bb6 100644
--- a/offapi/com/sun/star/awt/KeyModifier.idl
+++ b/offapi/com/sun/star/awt/KeyModifier.idl
@@ -34,7 +34,7 @@ published constants KeyModifier
const short SHIFT = 1;
- /** refers in the most cases to the "Ctrl" key (Cmd on Mac OS X).
+ /** refers in the most cases to the "Ctrl" key (Cmd on macOS).
*/
const short MOD1 = 2;
@@ -43,7 +43,7 @@ published constants KeyModifier
*/
const short MOD2 = 4;
- /** refers in the most cases to the "Ctrl" key (Mac OS X)
+ /** refers in the most cases to the "Ctrl" key (macOS)
*/
const short MOD3 = 8;
};
diff --git a/onlineupdate/source/update/updater/updater.cxx b/onlineupdate/source/update/updater/updater.cxx
index a4d31bdb0eb2..3cd4aa890aa0 100644
--- a/onlineupdate/source/update/updater/updater.cxx
+++ b/onlineupdate/source/update/updater/updater.cxx
@@ -709,7 +709,7 @@ static int ensure_copy(const NS_tchar *path, const NS_tchar *dest)
}
// This block size was chosen pretty arbitrarily but seems like a reasonable
- // compromise. For example, the optimal block size on a modern OS X machine
+ // compromise. For example, the optimal block size on a modern macOS machine
// is 100k */
const int blockSize = 32 * 1024;
void* buffer = malloc(blockSize);
@@ -2524,7 +2524,7 @@ ProcessReplaceRequest()
}
#ifdef MACOSX
- // On OS X, we need to remove the staging directory after its Contents
+ // On macOS, we need to remove the staging directory after its Contents
// directory has been moved.
NS_tchar updatedAppDir[MAXPATHLEN];
NS_tsnprintf(updatedAppDir, sizeof(updatedAppDir)/sizeof(updatedAppDir[0]),
@@ -2794,7 +2794,7 @@ UpdateThreadFunc(void * /*param*/)
{
#ifdef MACOSX
// If the update was successful we need to update the timestamp on the
- // top-level Mac OS X bundle directory so that Mac OS X's Launch Services
+ // top-level macOS bundle directory so that macOS's Launch Services
// picks up any major changes when the bundle is updated.
if (!sStagedUpdate && utimes(gInstallDirPath, nullptr) != 0)
{
diff --git a/osx/README b/osx/README
index 341b15bc718d..260a7ed48276 100644
--- a/osx/README
+++ b/osx/README
@@ -1,4 +1,4 @@
Just an Xcode project to make it easier to debug a running soffice
-instance on OS X. Not intended for other use. The Xcode project has
+instance on macOS. Not intended for other use. The Xcode project has
references to a fairly arbitrary bunch of source files from here and
-there in LO that I have happened to been debugging in Xcode on OS X. \ No newline at end of file
+there in LO that I have happened to been debugging in Xcode on macOS. \ No newline at end of file
diff --git a/sal/osl/unx/osxlocale.cxx b/sal/osl/unx/osxlocale.cxx
index 7bd611d85c17..f82ea1436c71 100644
--- a/sal/osl/unx/osxlocale.cxx
+++ b/sal/osl/unx/osxlocale.cxx
@@ -94,7 +94,7 @@ OUString macosx_getLocale()
buf.append("_");
append(buf, static_cast<CFStringRef>(CFArrayGetValueAtIndex(subs, 1)));
}
- // Append 'UTF-8' to the locale because the Mac OS X file
+ // Append 'UTF-8' to the locale because the macOS file
// system interface is UTF-8 based and sal tries to determine
// the file system locale from the locale information
buf.append(".UTF-8");
diff --git a/sal/osl/unx/salinit.cxx b/sal/osl/unx/salinit.cxx
index bfec16a96677..81a2d02ca31e 100644
--- a/sal/osl/unx/salinit.cxx
+++ b/sal/osl/unx/salinit.cxx
@@ -46,7 +46,7 @@ extern "C" {
void sal_detail_initialize(int argc, char ** argv) {
#if defined MACOSX && !HAVE_FEATURE_MACOSX_SANDBOX
- // On OS X when not sandboxed, soffice can restart itself via exec (see
+ // On macOS when not sandboxed, soffice can restart itself via exec (see
// restartOnMac in desktop/source/app/app.cxx), which leaves all file
// descriptors open, which in turn can have unwanted effects (see
// <https://bugs.libreoffice.org/show_bug.cgi?id=50603> "Unable to update
@@ -58,7 +58,7 @@ void sal_detail_initialize(int argc, char ** argv) {
// yet that might already have opened some fds); this is done for all kinds
// of processes here, not just soffice, but hopefully none of our processes
// rely on being spawned with certain fds already open. Unfortunately, Mac
- // OS X appears to have no better interface to close all fds (like
+ // macOS appears to have no better interface to close all fds (like
// closefrom):
long openMax = sysconf(_SC_OPEN_MAX);
if (openMax == -1) {
diff --git a/sal/osl/unx/security.cxx b/sal/osl/unx/security.cxx
index a7a47640c693..e545842290dc 100644
--- a/sal/osl/unx/security.cxx
+++ b/sal/osl/unx/security.cxx
@@ -72,7 +72,7 @@ static bool sysconf_SC_GETPW_R_SIZE_MAX(std::size_t * value) {
*value = static_cast<std::size_t>(m);
return true;
#else
- /* some platforms like Mac OS X 1.3 do not define _SC_GETPW_R_SIZE_MAX: */
+ /* some platforms like macOS 1.3 do not define _SC_GETPW_R_SIZE_MAX: */
return false;
#endif
}
diff --git a/sal/osl/unx/signal.cxx b/sal/osl/unx/signal.cxx
index 3ea564e14736..085f14d8ec0c 100644
--- a/sal/osl/unx/signal.cxx
+++ b/sal/osl/unx/signal.cxx
@@ -294,7 +294,7 @@ bool onInitSignal()
}
}
- /* Clear signal mask inherited from parent process (on Mac OS X, upon a
+ /* Clear signal mask inherited from parent process (on macOS, upon a
crash soffice re-execs itself from within the signal handler, so the
second soffice would have the guilty signal blocked and would freeze upon
encountering a similar crash again): */
diff --git a/sal/osl/unx/system.cxx b/sal/osl/unx/system.cxx
index dee35f5c3b92..2abbc24c0bd4 100644
--- a/sal/osl/unx/system.cxx
+++ b/sal/osl/unx/system.cxx
@@ -30,7 +30,7 @@
#if defined(MACOSX) || defined(IOS) || defined(OPENBSD) || defined(NETBSD) || defined(HAIKU)
-//No mutex needed on Mac OS X, gethostbyname is thread safe
+//No mutex needed on macOS, gethostbyname is thread safe
#if defined(MACOSX)
diff --git a/sal/osl/unx/uunxapi.cxx b/sal/osl/unx/uunxapi.cxx
index c3cccabb4d9e..b36c3ddc1790 100644
--- a/sal/osl/unx/uunxapi.cxx
+++ b/sal/osl/unx/uunxapi.cxx
@@ -379,7 +379,7 @@ int utime_c(const char *cpPath, struct utimbuf *times)
int ftruncate_with_name(int fd, sal_uInt64 uSize, rtl_String* path)
{
- /* When sandboxed on OS X, ftruncate(), even if it takes an
+ /* When sandboxed on macOS, ftruncate(), even if it takes an
* already open file descriptor which was returned from an open()
* call already checked by the sandbox, still requires a security
* scope bookmark for the file to be active in case the file is
diff --git a/sal/qa/osl/module/osl_Module.cxx b/sal/qa/osl/module/osl_Module.cxx
index 97d5cc1beaf4..65be1ffacab1 100644
--- a/sal/qa/osl/module/osl_Module.cxx
+++ b/sal/qa/osl/module/osl_Module.cxx
@@ -131,7 +131,7 @@ namespace osl_Module
void getUrlFromAddress_002( )
{
#if !defined( MACOSX )
- // TODO: Find out why this fails on Mac OS X
+ // TODO: Find out why this fails on macOS
::osl::Module aMod( getDllURL( ) );
FuncPtr pFunc = reinterpret_cast<FuncPtr>(aMod.getSymbol( "firstfunc" ));
@@ -260,7 +260,7 @@ namespace osl_Module
void getSymbol_001( )
{
#if !defined( MACOSX )
- // TODO: Find out why this fails on Mac OS X
+ // TODO: Find out why this fails on macOS
::osl::Module aMod( getDllURL( ) );
FuncPtr pFunc = reinterpret_cast<FuncPtr>(aMod.getSymbol( "firstfunc" ));
bRes = false;
@@ -289,7 +289,7 @@ namespace osl_Module
void optr_oslModule_001( )
{
#if !defined( MACOSX )
- // TODO: Find out why this fails on Mac OS X
+ // TODO: Find out why this fails on macOS
::osl::Module aMod;
bRes = ( static_cast<oslModule>(aMod) == nullptr );
@@ -308,7 +308,7 @@ namespace osl_Module
void optr_oslModule_002( )
{
#if !defined( MACOSX )
- // TODO: Find out why this fails on Mac OS X
+ // TODO: Find out why this fails on macOS
::osl::Module aMod( getDllURL( ) );
OUString funcName( "firstfunc" );
@@ -341,7 +341,7 @@ namespace osl_Module
void getFunctionSymbol_001( )
{
#if !defined( MACOSX )
- // TODO: Find out why this fails on Mac OS X
+ // TODO: Find out why this fails on macOS
::osl::Module aMod( getDllURL( ) );
oslGenericFunction oslFunc = aMod.getFunctionSymbol( "firstfunc" );
OUString aLibraryURL;
diff --git a/sal/rtl/math.cxx b/sal/rtl/math.cxx
index 447aabc365f8..14b0577532ab 100644
--- a/sal/rtl/math.cxx
+++ b/sal/rtl/math.cxx
@@ -1270,7 +1270,7 @@ double SAL_CALL rtl_math_log1p(double fValue) SAL_THROW_EXTERN_C()
{
#ifdef __APPLE__
if (fValue == -0.0)
- return fValue; // OS X 10.8 libc returns 0.0 for -0.0
+ return fValue; // macOS 10.8 libc returns 0.0 for -0.0
#endif
return log1p(fValue);
diff --git a/salhelper/source/gcc3.map b/salhelper/source/gcc3.map
index 54c5eb4fa51d..3d0d90d4aae0 100644
--- a/salhelper/source/gcc3.map
+++ b/salhelper/source/gcc3.map
@@ -34,7 +34,7 @@ UDK_3_0_0 { # should have been UDK_3.0
# Introducing a question mark at the end because of
# marginal type discrepancy there is a difference in the
- # mangled name between Linux and Mac OS X, see #i69351#
+ # mangled name between Linux and macOS, see #i69351#
_ZN9salhelper21SimpleReferenceObjectnwE?; # salhelper::SimpleReferenceObject::operator new (std::size_t)
_ZNK9salhelper18ORealDynamicLoader6getApiEv;
@@ -55,7 +55,7 @@ UDK_3.1 {
# Introducing a wildcard right in the middle because due to
# marginal type discrepancy there is a difference in the
- # mangled name between Linux and Mac OS X see #i69351#
+ # mangled name between Linux and macOS see #i69351#
_ZN9salhelper21SimpleReferenceObjectnwE?RKSt9nothrow_t; # salhelper::SimpleReferenceObject::operator new (std::size_t, std::nothrow_t const&)
_ZN9salhelper9ConditionC1ERN3osl5MutexE;
diff --git a/sc/qa/unit/subsequent_export-test.cxx b/sc/qa/unit/subsequent_export-test.cxx
index f084ad015f29..fcfb60f3fbf7 100644
--- a/sc/qa/unit/subsequent_export-test.cxx
+++ b/sc/qa/unit/subsequent_export-test.cxx
@@ -754,7 +754,7 @@ void ScExportTest::testCommentExportXLSX_2_XLSX()
#if HAVE_MORE_FONTS
void ScExportTest::testCustomColumnWidthExportXLSX()
{
- //tdf#100946 FILESAVE Excel on OS X ignored column widths in XLSX last saved by LO
+ //tdf#100946 FILESAVE Excel on macOS ignored column widths in XLSX last saved by LO
ScDocShellRef xShell = loadDoc("custom_column_width.", FORMAT_ODS);
CPPUNIT_ASSERT(xShell.is());
diff --git a/scripting/java/com/sun/star/script/framework/provider/SwingInvocation.java b/scripting/java/com/sun/star/script/framework/provider/SwingInvocation.java
index c0ff3dab91db..af563fa8e661 100644
--- a/scripting/java/com/sun/star/script/framework/provider/SwingInvocation.java
+++ b/scripting/java/com/sun/star/script/framework/provider/SwingInvocation.java
@@ -20,7 +20,7 @@ package com.sun.star.script.framework.provider;
import javax.swing.SwingUtilities;
-// On Mac OS X, AWT/Swing must not be accessed from the AppKit thread, so call
+// On macOS, AWT/Swing must not be accessed from the AppKit thread, so call
// SwingUtilities.invokeLater always on a fresh thread to avoid that problem
// (also, the current thread must not wait for that fresh thread to terminate,
// as that would cause a deadlock if this thread is the AppKit thread):
diff --git a/setup_native/source/mac/Info.plist.langpack b/setup_native/source/mac/Info.plist.langpack
index 361a4b418406..2847040e3bbc 100644
--- a/setup_native/source/mac/Info.plist.langpack
+++ b/setup_native/source/mac/Info.plist.langpack
@@ -21,7 +21,7 @@
<dict>
<key>CFBundleDevelopmentRegion</key>
<string>English</string>
- <!-- UTI declarations for OS X >= 10.4 -->
+ <!-- UTI declarations for macOS >= 10.4 -->
<key>UTExportedTypeDeclarations</key>
<key>UTImportedTypeDeclarations</key>
diff --git a/sfx2/source/dialog/filedlghelper.cxx b/sfx2/source/dialog/filedlghelper.cxx
index 0e5a3610ee3e..c6133a2bf243 100644
--- a/sfx2/source/dialog/filedlghelper.cxx
+++ b/sfx2/source/dialog/filedlghelper.cxx
@@ -1218,7 +1218,7 @@ void FileDialogHelper_Impl::preExecute()
// through before it returns from execution
mnPostUserEventId = Application::PostUserEvent( LINK( this, FileDialogHelper_Impl, InitControls ) );
#else
- // However, the Mac OS X implementation's pickers run modally in execute and so the event doesn't
+ // However, the macOS implementation's pickers run modally in execute and so the event doesn't
// get through in time... so we call the methods directly
enablePasswordBox( true );
updateFilterOptionsBox( );
diff --git a/shell/source/backends/localebe/localebackend.cxx b/shell/source/backends/localebe/localebackend.cxx
index 87d021a6d0e7..3cb381a721a9 100644
--- a/shell/source/backends/localebe/localebackend.cxx
+++ b/shell/source/backends/localebe/localebackend.cxx
@@ -114,9 +114,9 @@ namespace /* private */
CFStringRef sref = (CFGetTypeID(ref) == CFArrayGetTypeID()) ? static_cast<CFStringRef>(CFArrayGetValueAtIndex(static_cast<CFArrayRef>(ref), 0)) : static_cast<CFStringRef>(ref);
- // NOTE: this API is only available with Mac OS X >=10.3. We need to use it because
+ // NOTE: this API is only available with macOS >=10.3. We need to use it because
// Apple used non-ISO values on systems <10.2 like "German" for instance but didn't
- // upgrade those values during upgrade to newer Mac OS X versions. See also #i54337#
+ // upgrade those values during upgrade to newer macOS versions. See also #i54337#
return CFLocaleCreateCanonicalLocaleIdentifierFromString(kCFAllocatorDefault, sref);
}
diff --git a/solenv/bin/macosx-codesign-app-bundle b/solenv/bin/macosx-codesign-app-bundle
index f5ccff1475f1..85d74514585c 100755
--- a/solenv/bin/macosx-codesign-app-bundle
+++ b/solenv/bin/macosx-codesign-app-bundle
@@ -11,7 +11,7 @@ set -o pipefail
# from installer::simplepackage::create_package() in solenv/bin/modules/installer/simplepackage.pm
# and the test-install target in Makefile.in.
-test `uname` = Darwin || { echo This is for OS X only; exit 1; }
+test `uname` = Darwin || { echo This is for macOS only; exit 1; }
test $# = 1 || { echo Usage: $0 app-bundle; exit 1; }
diff --git a/solenv/bin/modules/installer/simplepackage.pm b/solenv/bin/modules/installer/simplepackage.pm
index f5337e59dc18..46f9f477d1b1 100644
--- a/solenv/bin/modules/installer/simplepackage.pm
+++ b/solenv/bin/modules/installer/simplepackage.pm
@@ -223,7 +223,7 @@ sub replace_variables_in_scriptfile
# Creating the "simple" package.
# "zip" for Windows
# "tar.gz" for all other platforms
-# additionally "dmg" on Mac OS X
+# additionally "dmg" on macOS
#############################################
sub create_package
@@ -405,7 +405,7 @@ sub create_package
{
my $subdir = "$tempdir/$packagename/$volume_name_classic_app.app/Contents/Resources";
if ( ! -d $subdir ) { installer::systemactions::create_directory($subdir); }
- # iterate over OS X localizations
+ # iterate over macOS localizations
foreach $lang ("ca", "cs", "da", "de", "el", "en", "es", "fi", "fr", "hr", "hu", "id", "it", "ja", "ko", "ms", "nl", "no", "pl", "pt", "pt_PT", "ro", "ru", "sk", "sv", "th", "tr", "uk", "vi", "zh_CN", "zh_TW")
{
installer::systemactions::create_directory($subdir . "/" . $lang . ".lproj");
diff --git a/solenv/gbuild/config.guess b/solenv/gbuild/config.guess
index a7448442748c..61b5c7b0f3f7 100755
--- a/solenv/gbuild/config.guess
+++ b/solenv/gbuild/config.guess
@@ -1324,9 +1324,9 @@ EOF
fi
fi
elif test "$UNAME_PROCESSOR" = i386 ; then
- # Avoid executing cc on OS X 10.9, as it ships with a stub
+ # Avoid executing cc on macOS 10.9, as it ships with a stub
# that puts up a graphical alert prompting to install
- # developer tools. Any system running Mac OS X 10.7 or
+ # developer tools. Any system running macOS 10.7 or
# later (Darwin 11 and later) is required to have a 64-bit
# processor. This is not true of the ARM version of Darwin
# that Apple uses in portable devices.
diff --git a/solenv/gbuild/platform/com_GCC_class.mk b/solenv/gbuild/platform/com_GCC_class.mk
index 4c3531934d5e..4b2786df1856 100644
--- a/solenv/gbuild/platform/com_GCC_class.mk
+++ b/solenv/gbuild/platform/com_GCC_class.mk
@@ -147,7 +147,7 @@ gb_ICU_PRECOMMAND := $(call gb_Helper_extend_ld_path,$(WORKDIR_FOR_BUILD)/Unpack
# UIConfig class
-# Mac OS X sort(1) cannot read a response file
+# macOS sort(1) cannot read a response file
define gb_UIConfig__command
$(call gb_Helper_abbreviate_dirs,\
$(SORT) -u $(UI_IMAGELISTS) /dev/null > $@ \
diff --git a/solenv/gbuild/platform/unittest-failed-MACOSX.sh b/solenv/gbuild/platform/unittest-failed-MACOSX.sh
index 7994dbd56b01..049da92b4c3c 100755
--- a/solenv/gbuild/platform/unittest-failed-MACOSX.sh
+++ b/solenv/gbuild/platform/unittest-failed-MACOSX.sh
@@ -19,7 +19,7 @@
cat << EOF
Error: a unit test failed, please do one of:
-make $1Test_$2 CPPUNITTRACE="lldb --" # for interactive debugging on OS X
+make $1Test_$2 CPPUNITTRACE="lldb --" # for interactive debugging on macOS
make $1Test_$2 VALGRIND=memcheck # for memory checking
You can limit the execution to just one particular test by:
diff --git a/solenv/maven/README.md b/solenv/maven/README.md
index 3ff8a137c85c..29f853fbb6e5 100644
--- a/solenv/maven/README.md
+++ b/solenv/maven/README.md
@@ -132,7 +132,7 @@ To install it system wide:
Put $HOME/watchman/bin/watchman in path or link to $HOME/bin/watchman.
-To install watchman on OS X:
+To install watchman on macOS:
----
brew install --HEAD watchman
@@ -230,7 +230,7 @@ credentials:
</settings>
----
-It can also be included in the key chain on OS X.
+It can also be included in the key chain on macOS.
== Update Versions
diff --git a/soltools/cpp/_getopt.c b/soltools/cpp/_getopt.c
index 8f9181ccad52..b41147c3e1d5 100644
--- a/soltools/cpp/_getopt.c
+++ b/soltools/cpp/_getopt.c
@@ -49,7 +49,7 @@ int
}
else if (strcmp(argv[optind], "-isysroot") == 0)
{
- // skip Mac OS X SDK selection flags
+ // skip macOS SDK selection flags
optind++; optind++;
}
}
diff --git a/tools/source/datetime/systemdatetime.cxx b/tools/source/datetime/systemdatetime.cxx
index 40e4edfd05c3..cd07728ece98 100644
--- a/tools/source/datetime/systemdatetime.cxx
+++ b/tools/source/datetime/systemdatetime.cxx
@@ -69,7 +69,7 @@ bool GetSystemDateTime(sal_Int32* pDate, sal_Int64* pTime)
#else
struct timespec tsTime;
#if defined(__MACH__)
- // OS X does not have clock_gettime, use clock_get_time
+ // macOS does not have clock_gettime, use clock_get_time
clock_serv_t cclock;
mach_timespec_t mts;
host_get_clock_service(mach_host_self(), CALENDAR_CLOCK, &cclock);
diff --git a/ucb/source/ucp/file/filtask.cxx b/ucb/source/ucp/file/filtask.cxx
index f3f32ccfe18b..c8996afedf0b 100644
--- a/ucb/source/ucp/file/filtask.cxx
+++ b/ucb/source/ucp/file/filtask.cxx
@@ -2090,7 +2090,7 @@ bool TaskManager::ensuredir( sal_Int32 CommandId,
// arbitrary (?) directory does not seem to cause any sandbox
// violation, while opendir() does. (Sorry I could not be bothered
// to use some complex cross-platform abstraction over stat() here
- // in this OS X specific code block.)
+ // in this macOS specific code block.)
OUString aDirName;
struct stat s;
diff --git a/udkapi/com/sun/star/lang/SystemDependent.idl b/udkapi/com/sun/star/lang/SystemDependent.idl
index 1764eb98edd4..4d1c3c5e6b88 100644
--- a/udkapi/com/sun/star/lang/SystemDependent.idl
+++ b/udkapi/com/sun/star/lang/SystemDependent.idl
@@ -70,7 +70,7 @@ published constants SystemDependent
/** The called interface method returns a value specified for <em>OS/2</em>.
*/
const short SYSTEM_OS2 = 4;
- /** The called interface method returns a value specified for <em>Mac OS X</em>.
+ /** The called interface method returns a value specified for <em>macOS</em>.
*/
const short SYSTEM_MAC = 5;
diff --git a/vcl/README b/vcl/README
index 5a869ef77b9f..1169cdf1f660 100644
--- a/vcl/README
+++ b/vcl/README
@@ -17,13 +17,13 @@ android/
+ Android backend
osx/
- + OS X backend
+ + macOS backend
ios/
+ iOS backend
quartz/
- + code common to OS X and iOS
+ + code common to macOS and iOS
win/
+ Windows backend
diff --git a/vcl/osx/salframe.cxx b/vcl/osx/salframe.cxx
index 50a899c9da4d..2a8eeb0b0af1 100644
--- a/vcl/osx/salframe.cxx
+++ b/vcl/osx/salframe.cxx
@@ -1185,7 +1185,7 @@ SAL_WNODEPRECATED_DECLARATIONS_POP
aStyleSettings.SetToolbarIconSize( ToolbarIconSize::Large );
- // TODO: better mapping of OS X<->LibreOffice font settings
+ // TODO: better mapping of macOS<->LibreOffice font settings
vcl::Font aLabelFont( getFont( [NSFont labelFontOfSize: 0], nDPIY, aAppFont ) );
aStyleSettings.BatchSetFonts( aAppFont, aLabelFont );
vcl::Font aMenuFont( getFont( [NSFont menuFontOfSize: 0], nDPIY, aAppFont ) );
@@ -1220,7 +1220,7 @@ SAL_WNODEPRECATED_DECLARATIONS_POP
aStyleSettings.SetCursorBlinkTime( 500 );
- // no mnemonics on OS X
+ // no mnemonics on macOS
aStyleSettings.SetOptions( aStyleSettings.GetOptions() | StyleSettingsOptions::NoMnemonics );
getAppleScrollBarVariant(aStyleSettings);
diff --git a/vcl/osx/salnativewidgets.cxx b/vcl/osx/salnativewidgets.cxx
index 0026d68a0dbd..cab5ae940a3c 100644
--- a/vcl/osx/salnativewidgets.cxx
+++ b/vcl/osx/salnativewidgets.cxx
@@ -803,7 +803,7 @@ bool AquaSalGraphics::drawNativeControl(ControlType nType,
aTextDrawInfo.state=getState( nState );
aTextDrawInfo.isFocused=false;
- rc.size.width+=1;//else there's a white space because an OS X theme has no 3D border
+ rc.size.width+=1; // else there's a white space because a macOS theme has no 3D border
rc.size.height+=1;
HIThemeDrawFrame(&rc, &aTextDrawInfo, mrContext, kHIThemeOrientationNormal);
@@ -825,7 +825,7 @@ bool AquaSalGraphics::drawNativeControl(ControlType nType,
aTextDrawInfo.state=getState( nState );
aTextDrawInfo.isFocused=false;
- rc.size.width += 1; // else there may be a white space because an OS X theme has no 3D border
+ rc.size.width += 1; // else there may be a white space because a macOS theme has no 3D border
// change rc so that the frame will encompass only the content region
// see counterpart in GetNativeControlRegion
rc.size.width += 2;
diff --git a/vcl/quartz/ctfonts.cxx b/vcl/quartz/ctfonts.cxx
index e98fac83b0f6..314756391664 100644
--- a/vcl/quartz/ctfonts.cxx
+++ b/vcl/quartz/ctfonts.cxx
@@ -371,7 +371,7 @@ FontAttributes DevFontFromCTFontDescriptor( CTFontDescriptorRef pFD, bool* bFont
// get font-enabled status
if( bFontEnabled )
{
- int bEnabled = TRUE; // by default (and when we're on OS X < 10.6) it's "enabled"
+ int bEnabled = TRUE; // by default (and when we're on macOS < 10.6) it's "enabled"
CFNumberRef pEnabled = static_cast<CFNumberRef>(CTFontDescriptorCopyAttribute( pFD, kCTFontEnabledAttribute ));
CFNumberGetValue( pEnabled, kCFNumberIntType, &bEnabled );
*bFontEnabled = bEnabled;
diff --git a/vcl/source/control/edit.cxx b/vcl/source/control/edit.cxx
index 795f1e828f4e..c1337c5dfe24 100644
--- a/vcl/source/control/edit.cxx
+++ b/vcl/source/control/edit.cxx
@@ -441,7 +441,7 @@ void Edit::ImplInvalidateOrRepaint()
if( IsPaintTransparent() )
{
Invalidate();
- // FIXME: this is currently only on OS X
+ // FIXME: this is currently only on macOS
if( ImplGetSVData()->maNWFData.mbNoFocusRects )
Update();
}
@@ -1874,7 +1874,7 @@ void Edit::GetFocus()
ImplShowCursor();
- // FIXME: this is currently only on OS X
+ // FIXME: this is currently only on macOS
// check for other platforms that need similar handling
if( ImplGetSVData()->maNWFData.mbNoFocusRects &&
IsNativeWidgetEnabled() &&
@@ -1908,7 +1908,7 @@ void Edit::LoseFocus()
if ( !mpSubEdit )
{
- // FIXME: this is currently only on OS X
+ // FIXME: this is currently only on macOS
// check for other platforms that need similar handling
if( ImplGetSVData()->maNWFData.mbNoFocusRects &&
IsNativeWidgetEnabled() &&
@@ -2359,7 +2359,7 @@ void Edit::Modify()
// #i13677# notify edit listeners about caret position change
CallEventListeners( VclEventId::EditCaretChanged );
- // FIXME: this is currently only on OS X
+ // FIXME: this is currently only on macOS
// check for other platforms that need similar handling
if( ImplGetSVData()->maNWFData.mbNoFocusRects &&
IsNativeWidgetEnabled() &&
diff --git a/vcl/source/control/scrbar.cxx b/vcl/source/control/scrbar.cxx
index e2b000cdd2ea..7ff22a104b60 100644
--- a/vcl/source/control/scrbar.cxx
+++ b/vcl/source/control/scrbar.cxx
@@ -30,9 +30,9 @@
/* #i77549#
HACK: for scrollbars in case of thumb rect, page up and page down rect we
- abuse the HitTestNativeScrollbar interface. All theming engines but OS X
+ abuse the HitTestNativeScrollbar interface. All theming engines but macOS
are actually able to draw the thumb according to our internal representation.
- However OS X draws a little outside. The canonical way would be to enhance the
+ However macOS draws a little outside. The canonical way would be to enhance the
HitTestNativeScrollbar passing a ScrollbarValue additionally so all necessary
information is available in the call.
.
diff --git a/vcl/source/control/spinfld.cxx b/vcl/source/control/spinfld.cxx
index dd7d6561c554..263af6f90179 100644
--- a/vcl/source/control/spinfld.cxx
+++ b/vcl/source/control/spinfld.cxx
@@ -848,7 +848,7 @@ bool SpinField::PreNotify(NotifyEvent& rNEvt)
tools::Rectangle* pLastRect = ImplFindPartRect( GetLastPointerPosPixel() );
if( pRect != pLastRect || (pMouseEvt->IsLeaveWindow() || pMouseEvt->IsEnterWindow()) )
{
- // FIXME: this is currently only on OS X
+ // FIXME: this is currently only on macOS
// check for other platforms that need similar handling
if (ImplGetSVData()->maNWFData.mbNoFocusRects && IsNativeWidgetEnabled() &&
IsNativeControlSupported(ControlType::Editbox, ControlPart::Entire))
diff --git a/vcl/source/filter/igif/gifread.cxx b/vcl/source/filter/igif/gifread.cxx
index 22b916ca0198..745440853f55 100644
--- a/vcl/source/filter/igif/gifread.cxx
+++ b/vcl/source/filter/igif/gifread.cxx
@@ -192,7 +192,7 @@ void GIFReader::CreateBitmaps(long nWidth, long nHeight, BitmapPalette* pPal,
// 32-bit system. We have at least one unit tests that is expected
// to fail (loading a 65535*65535 size GIF
// svtools/qa/cppunit/data/gif/fail/CVE-2008-5937-1.gif), but
- // which doesn't fail on 64-bit Mac OS X at least. Why the loading
+ // which doesn't fail on 64-bit macOS at least. Why the loading
// fails on 64-bit Linux, no idea.
if (nCombinedPixSize >= SAL_MAX_INT32/3*2)
{
diff --git a/vcl/source/treelist/transfer.cxx b/vcl/source/treelist/transfer.cxx
index 4d6ef1f9b1cf..40110d951b43 100644
--- a/vcl/source/treelist/transfer.cxx
+++ b/vcl/source/treelist/transfer.cxx
@@ -970,7 +970,7 @@ void TransferableHelper::StartDrag( vcl::Window* pWindow, sal_Int8 nDnDSourceAct
const Point aPt( pWindow->GetPointerPosPixel() );
- // On Mac OS X we are forced to execute 'startDrag' synchronously
+ // On macOS we are forced to execute 'startDrag' synchronously
// contrary to the XDragSource interface specification because
// we can receive drag events from the system only in the main
// thread
diff --git a/vcl/source/window/brdwin.cxx b/vcl/source/window/brdwin.cxx
index 9428ee709599..549db302ba9f 100644
--- a/vcl/source/window/brdwin.cxx
+++ b/vcl/source/window/brdwin.cxx
@@ -436,7 +436,7 @@ void ImplSmallBorderWindowView::Init( OutputDevice* pDev, long nWidth, long nHei
}
else
{
- // FIXME: this is currently only on OS X, check with other
+ // FIXME: this is currently only on macOS, check with other
// platforms
if( ImplGetSVData()->maNWFData.mbNoFocusRects && !( nBorderStyle & WindowBorderStyle::NWF ) )
{
@@ -673,9 +673,9 @@ void ImplSmallBorderWindowView::DrawWindow(vcl::RenderContext& rRenderContext, c
nState |= ControlState::FOCUSED;
else if(mbNWFBorder)
{
- // FIXME: this is currently only on OS X, see if other platforms can profit
+ // FIXME: this is currently only on macOS, see if other platforms can profit
- // FIXME: for OS X focus rings all controls need to support GetNativeControlRegion
+ // FIXME: for macOS focus rings all controls need to support GetNativeControlRegion
// for the dropdown style
if (pCtrl->HasFocus() || pCtrl->HasChildPathFocus())
nState |= ControlState::FOCUSED;
diff --git a/vcl/source/window/mouse.cxx b/vcl/source/window/mouse.cxx
index 19851303499b..f0297d26a1e4 100644
--- a/vcl/source/window/mouse.cxx
+++ b/vcl/source/window/mouse.cxx
@@ -742,7 +742,7 @@ Reference< css::datatransfer::dnd::XDragSource > Window::GetDragSource()
aDragSourceAL[ 1 ] <<= static_cast<sal_uInt64>( reinterpret_cast<sal_IntPtr>(pEnvData->hWnd) );
aDropTargetAL[ 0 ] <<= static_cast<sal_uInt64>( reinterpret_cast<sal_IntPtr>(pEnvData->hWnd) );
#elif defined MACOSX
- /* FIXME: Mac OS X specific dnd interface does not exist! *
+ /* FIXME: macOS specific dnd interface does not exist! *
* Using Windows based dnd as a temporary solution */
aDragSourceSN = "com.sun.star.datatransfer.dnd.OleDragSource";
aDropTargetSN = "com.sun.star.datatransfer.dnd.OleDropTarget";
diff --git a/vcl/source/window/window.cxx b/vcl/source/window/window.cxx
index 2b835fd81796..99e3db2abc97 100644
--- a/vcl/source/window/window.cxx
+++ b/vcl/source/window/window.cxx
@@ -1188,7 +1188,7 @@ void Window::ImplInitAppFontData( vcl::Window const * pWindow )
pSVData->maGDIData.mnAppFontY = nTextHeight * 10;
#ifdef MACOSX
- // FIXME: this is currently only on OS X, check with other
+ // FIXME: this is currently only on macOS, check with other
// platforms
if( pSVData->maNWFData.mbNoFocusRects )
{
diff --git a/vcl/unx/generic/window/salframe.cxx b/vcl/unx/generic/window/salframe.cxx
index ab0700e948e2..face14778fd0 100644
--- a/vcl/unx/generic/window/salframe.cxx
+++ b/vcl/unx/generic/window/salframe.cxx
@@ -2542,7 +2542,7 @@ static sal_uInt16 sal_GetCode( int state )
nCode |= KEY_MOD2;
// Map Meta/Super modifier to MOD3 on all Unix systems
- // except Mac OS X
+ // except macOS
if( state & Mod3Mask )
nCode |= KEY_MOD3;
@@ -3132,7 +3132,7 @@ bool X11SalFrame::HandleKeyEvent( XKeyEvent *pEvent )
nModMask = KEY_SHIFT;
break;
// Map Meta/Super keys to MOD3 modifier on all Unix systems
- // except Mac OS X
+ // except macOS
case XK_Meta_L:
case XK_Super_L:
nExtModMask = ModKeyFlags::LeftMod3;
diff --git a/vcl/unx/gtk/gtksalframe.cxx b/vcl/unx/gtk/gtksalframe.cxx
index 305a1c3048bf..899f1a1a291f 100644
--- a/vcl/unx/gtk/gtksalframe.cxx
+++ b/vcl/unx/gtk/gtksalframe.cxx
@@ -105,7 +105,7 @@ sal_uInt16 GtkSalFrame::GetKeyModCode( guint state )
nCode |= KEY_MOD2;
// Map Meta/Super keys to MOD3 modifier on all Unix systems
- // except Mac OS X
+ // except macOS
if ( (state & GDK_META_MASK ) || ( state & GDK_SUPER_MASK ) )
nCode |= KEY_MOD3;
return nCode;
@@ -3025,7 +3025,7 @@ gboolean GtkSalFrame::signalKey( GtkWidget*, GdkEventKey* pEvent, gpointer frame
nModMask = KEY_SHIFT;
break;
// Map Meta/Super to MOD3 modifier on all Unix systems
- // except Mac OS X
+ // except macOS
case GDK_KEY_Meta_L:
case GDK_KEY_Super_L:
nExtModMask = ModKeyFlags::LeftMod3;
diff --git a/vcl/unx/gtk3/gtk3gtkframe.cxx b/vcl/unx/gtk3/gtk3gtkframe.cxx
index 4e5271801b4d..d2d38b58f23c 100644
--- a/vcl/unx/gtk3/gtk3gtkframe.cxx
+++ b/vcl/unx/gtk3/gtk3gtkframe.cxx
@@ -3270,7 +3270,7 @@ gboolean GtkSalFrame::signalKey(GtkWidget* pWidget, GdkEventKey* pEvent, gpointe
nModMask = KEY_SHIFT;
break;
// Map Meta/Super to MOD3 modifier on all Unix systems
- // except Mac OS X
+ // except macOS
case GDK_KEY_Meta_L:
case GDK_KEY_Super_L:
nExtModMask = ModKeyFlags::LeftMod3;
diff --git a/bin/symbolstore.py b/bin/symbolstore.py
index e81c529259bd..7ddd8d2ac234 100755
--- a/bin/symbolstore.py
+++ b/bin/symbolstore.py
@@ -50,7 +50,7 @@
# -c : Copy debug info files to the same directory structure
# as sym files
# -a "<archs>" : Run dump_syms -a <arch> for each space separated
# cpu architecture in <archs> (only on OS X)
# -s <srcdir> : Use <srcdir> as the top source directory to
# generate relative filenames.
@@ -606,7 +606,7 @@ def main():
help="Copy debug info files into the same directory structure as symbol files")
parser.add_option("-a", "--archs",
action="store", dest="archs",
- help="Run dump_syms -a <arch> for each space separated cpu architecture in ARCHS (only on OS X)")
+ help="Run dump_syms -a <arch> for each space separated cpu architecture in ARCHS (only on macOS)")
parser.add_option("-s", "--srcdir",
action="store", dest="srcdir",
help="Use SRCDIR to determine relative paths to source files")
@@ -50,7 +50,7 @@
# as sym files
# -a "<archs>" : Run dump_syms -a <arch> for each space separated
-# cpu architecture in <archs> (only on OS X)
+# cpu architecture in <archs> (only on macOS)
# -s <srcdir> : Use <srcdir> as the top source directory to
# generate relative filenames.
diff --git a/lingucomponent/source/spellcheck/macosxspell/macspellimp.mm b/lingucomponent/source/spellcheck/macosxspell/macspellimp.mm
index 1c7434b45054..ba43a6bcaa7d 100644
--- a/lingucomponent/source/spellcheck/macosxspell/macspellimp.mm
+++ b/lingucomponent/source/spellcheck/macosxspell/macspellimp.mm
@@ -105,7 +105,7 @@ Sequence< Locale > SAL_CALL MacSpellChecker::getLocales()
if (!numdict) {
// invoke a dictionary manager to get the user dictionary list
// TODO How on Mac OS X?
// invoke a second dictionary manager to get the shared dictionary list
NSArray *aSpellCheckLanguages = [[NSSpellChecker sharedSpellChecker] availableLanguages];
@@ -526,7 +526,7 @@ OUString SAL_CALL
MacSpellChecker::getServiceDisplayName( const Locale& /*rLocale*/ )
{
MutexGuard aGuard( GetLinguMutex() );
- return OUString( "Mac OS X Spell Checker" );
+ return OUString( "macOS Spell Checker" );
}
@@ -105,7 +105,7 @@ Sequence< Locale > SAL_CALL MacSpellChecker::getLocales()
if (!numdict) {
// invoke a dictionary manager to get the user dictionary list
- // TODO How on Mac OS X?
+ // TODO How on macOS?
// invoke a second dictionary manager to get the shared dictionary list
NSArray *aSpellCheckLanguages = [[NSSpellChecker sharedSpellChecker] availableLanguages];